@@ -4,8 +4,8 @@ from typing import Dict, List, Optional, Tuple
 from hdx.utilities.text import multiple_replace
 from unidecode import unidecode
 
-from hdx.location import clean_name
 from hdx.location.country import Country
+from hdx.location.names import clean_name
 from hdx.location.phonetics import Phonetics
 
 logger = logging.getLogger(__name__)
@@ -15,7 +15,7 @@ class AdminOne:
     """AdminOne class which takes in pcodes and then maps names to those pcodes with fuzzy matching if necessary. The
     input configuration dictionary, admin_config, requires key admin1_info which is a list with values of the form:
     ::
-        {'iso3': 'AFG', 'pcode': 'AF01', 'name': 'Kabul'}
+        {"iso3": "AFG", "pcode": "AF01", "name": "Kabul"}
 
     Various other keys are optional:
     countries_fuzzy_try are countries (iso3 codes) for which to try fuzzy matching. Default is all countries.
@@ -27,21 +27,22 @@ class AdminOne:
         admin_config (Dict): Configuration dictionary
     """
 
-    _admininfo = None
-    pcodes = list()
-    pcode_lengths = dict()
-    name_to_pcode = dict()
-    pcode_to_name = dict()
-    pcode_to_iso3 = dict()
-
     def __init__(self, admin_config: Dict) -> None:
         admin_info1 = admin_config["admin1_info"]
         self.countries_fuzzy_try = admin_config.get("countries_fuzzy_try")
-        self.admin1_name_mappings = admin_config.get("admin1_name_mappings", dict())
+        self.admin1_name_mappings = admin_config.get(
+            "admin1_name_mappings", dict()
+        )
         self.admin1_name_replacements = admin_config.get(
             "admin1_name_replacements", dict()
         )
         self.admin1_fuzzy_dont = admin_config.get("admin1_fuzzy_dont", list())
+        self.pcodes = list()
+        self.pcode_lengths = dict()
+        self.name_to_pcode = dict()
+        self.pcode_to_name = dict()
+        self.pcode_to_iso3 = dict()
+
         for row in admin_info1:
             countryiso3 = row["iso3"]
             pcode = row.get("pcode")
@@ -86,7 +87,11 @@ class AdminOne:
         country_pcodelength = self.pcode_lengths.get(countryiso3)
         if not country_pcodelength:
             return None
-        if pcode_length == country_pcodelength or pcode_length < 4 or pcode_length > 6:
+        if (
+            pcode_length == country_pcodelength
+            or pcode_length < 4
+            or pcode_length > 6
+        ):
             return None
         if country_pcodelength == 4:
             pcode = f"{Country.get_iso2_from_iso3(pcode[:3])}{pcode[-2:]}"
@@ -139,9 +144,6 @@ class AdminOne:
         if not name_to_pcode:
             self.errors.add((scrapername, countryiso3))
             return None
-        if name.lower() in self.admin1_fuzzy_dont:
-            self.ignored.add((scrapername, countryiso3, name))
-            return None
         adm1_name_lookup = clean_name(name)
         adm1_name_lookup2 = multiple_replace(
             adm1_name_lookup, self.admin1_name_replacements
@@ -149,6 +151,9 @@ class AdminOne:
         pcode = name_to_pcode.get(
             adm1_name_lookup, name_to_pcode.get(adm1_name_lookup2)
         )
+        if not pcode and name.lower() in self.admin1_fuzzy_dont:
+            self.ignored.add((scrapername, countryiso3, name))
+            return None
         if not pcode:
             for map_name in name_to_pcode:
                 if adm1_name_lookup in map_name:
@@ -206,7 +211,13 @@ class AdminOne:
             map_name = map_names[matching_index]
             pcode = name_to_pcode[map_name]
             self.matches.add(
-                (scrapername, countryiso3, name, self.pcode_to_name[pcode], "fuzzy")
+                (
+                    scrapername,
+                    countryiso3,
+                    name,
+                    self.pcode_to_name[pcode],
+                    "fuzzy",
+                )
             )
         return pcode
 
@@ -280,9 +291,7 @@ class AdminOne:
             if len(error) == 2:
                 line = f"{error[0]} - Could not find {error[1]} in map names!"
             else:
-                line = (
-                    f"{error[0]} - {error[1]}: Could not find {error[2]} in map names!"
-                )
+                line = f"{error[0]} - {error[1]}: Could not find {error[2]} in map names!"
             logger.error(line)
             output.append(line)
         return output
