@@ -2,11 +2,13 @@
 import copy
 import logging
 import re
+from string import punctuation
 from typing import Dict, List, Optional, Tuple, TypeVar, Union
 
 import hxl
 from hdx.utilities.path import script_dir_plus_file
 from hdx.utilities.text import get_words_in_sentence
+from hxl import InputOptions
 
 ExceptionUpperBound = TypeVar("T", bound="Exception")
 
@@ -235,7 +237,7 @@ class Country:
                         "Countries & Territories Taxonomy MVP - C&T Taxonomy with HXL Tags.csv",
                         Country,
                     ),
-                    allow_local=True,
+                    InputOptions(allow_local=True),
                 )
             cls.set_countriesdata(countries)
         return cls._countriesdata
@@ -700,6 +702,7 @@ class Country:
         if len(countryupper_words) > 1:
             countryupper = countryupper_words[0]
         if countryupper:
+            countryupper = countryupper.strip(punctuation)
             words.remove(countryupper)
         return countryupper, words
 
