@@ -2,6 +2,7 @@
 import hxl
 import pytest
 from hdx.utilities.path import script_dir_plus_file
+from hxl import InputOptions
 
 from hdx.location.country import Country
 
@@ -590,6 +591,9 @@ class TestCountry:
             False,
         )
         assert Country.get_iso3_country_code_fuzzy("Taiwan") == ("TWN", True)
+        assert Country.get_iso3_country_code_fuzzy("Taiwan*") == ("TWN", False)
+        assert Country.get_iso3_country_code_fuzzy("Kosovo") == (None, False)
+        assert Country.get_iso3_country_code_fuzzy("Kosovo*") == (None, False)
         with pytest.raises(ValueError):
             Country.get_iso3_country_code("abc", exception=ValueError)
         with pytest.raises(ValueError):
@@ -630,7 +634,7 @@ class TestCountry:
     def test_ocha_feed_file_working(self):
         countries = hxl.data(
             script_dir_plus_file("Countries_UZB_Deleted.csv", TestCountry),
-            allow_local=True,
+            InputOptions(allow_local=True),
         )
         Country.set_countriesdata(countries)
         assert Country.get_iso3_country_code("UZBEKISTAN") is None
